# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feature_extract.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='feature_extract.proto',
  package='extractfeature',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x66\x65\x61ture_extract.proto\x12\x0e\x65xtractfeature\"#\n\x0e\x46\x65\x61tureRequest\x12\x11\n\tfile_data\x18\x01 \x01(\x0c\"\x1e\n\x0c\x46\x65\x61tureReply\x12\x0e\n\x06vector\x18\x01 \x01(\x0c\x32W\n\x07\x45xtract\x12L\n\nGetFeature\x12\x1e.extractfeature.FeatureRequest\x1a\x1c.extractfeature.FeatureReply\"\x00\x42<\n\x1cio.stylelens.feature.extractB\x13\x46\x65\x61tureExtractProtoP\x01\xa2\x02\x04STYLb\x06proto3')
)




_FEATUREREQUEST = _descriptor.Descriptor(
  name='FeatureRequest',
  full_name='extractfeature.FeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_data', full_name='extractfeature.FeatureRequest.file_data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=76,
)


_FEATUREREPLY = _descriptor.Descriptor(
  name='FeatureReply',
  full_name='extractfeature.FeatureReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='extractfeature.FeatureReply.vector', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=108,
)

DESCRIPTOR.message_types_by_name['FeatureRequest'] = _FEATUREREQUEST
DESCRIPTOR.message_types_by_name['FeatureReply'] = _FEATUREREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureRequest = _reflection.GeneratedProtocolMessageType('FeatureRequest', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREREQUEST,
  __module__ = 'feature_extract_pb2'
  # @@protoc_insertion_point(class_scope:extractfeature.FeatureRequest)
  ))
_sym_db.RegisterMessage(FeatureRequest)

FeatureReply = _reflection.GeneratedProtocolMessageType('FeatureReply', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREREPLY,
  __module__ = 'feature_extract_pb2'
  # @@protoc_insertion_point(class_scope:extractfeature.FeatureReply)
  ))
_sym_db.RegisterMessage(FeatureReply)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\034io.stylelens.feature.extractB\023FeatureExtractProtoP\001\242\002\004STYL'))

_EXTRACT = _descriptor.ServiceDescriptor(
  name='Extract',
  full_name='extractfeature.Extract',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=110,
  serialized_end=197,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeature',
    full_name='extractfeature.Extract.GetFeature',
    index=0,
    containing_service=None,
    input_type=_FEATUREREQUEST,
    output_type=_FEATUREREPLY,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTRACT)

DESCRIPTOR.services_by_name['Extract'] = _EXTRACT

# @@protoc_insertion_point(module_scope)
